==> open-xchange-mobile-api-facade_1.0.1.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.1/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/endpoints/FoldersEndpoint.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.endpoints;

import java.util.List;

import javax.annotation.security.PermitAll;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.endpoints.requests.ExamineFolderRequestBody;
import com.openexchange.mobile.api.facade.endpoints.requests.FolderCreateRequestBody;
import com.openexchange.mobile.api.facade.endpoints.requests.FolderRequestBody;
import com.openexchange.mobile.api.facade.endpoints.responses.AccountsResponseBody;
import com.openexchange.mobile.api.facade.endpoints.responses.CreateFolderResponseBody;
import com.openexchange.mobile.api.facade.endpoints.responses.ExamineFolderResponseBody;
import com.openexchange.mobile.api.facade.models.Account;
import com.openexchange.mobile.api.facade.models.CreatedFolder;
import com.openexchange.mobile.api.facade.models.ExamineResult;
import com.openexchange.mobile.api.facade.services.FoldersService;
import com.openexchange.mobile.api.facade.utils.JacksonUtil;
import com.openexchange.mobile.api.facade.utils.RequestUtil;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

@Path("/api-facade/v1/folders")
@RequiredArgsConstructor
@PermitAll
@Slf4j
public class FoldersEndpoint {

    private final FoldersService foldersService;

    @POST
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response createFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Create folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        FolderCreateRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderCreateRequestBody.class);
        CreatedFolder folder = foldersService.createFolder(sessionData, requestBody.getParentFolderId(), requestBody.getName());
        CreateFolderResponseBody responseBody = new CreateFolderResponseBody(folder);
        return RequestUtil.jsonResponse(201, responseBody);
    }

    @DELETE
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response deleteFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Delete folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
        foldersService.deleteFolder(sessionData, requestBody.getFolderId());
        return RequestUtil.emptyJsonResponse();
    }

    @DELETE
    @Path("/clear")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response expungeFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Clear folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
        foldersService.clearFolder(sessionData, requestBody.getFolderId());
        return RequestUtil.emptyJsonResponse();
    }

    @GET
    @Path("/mail")
    @Produces(MediaType.APPLICATION_JSON)
    public Response getAllMailFolders(@Context HttpServletRequest request) {
        log.info("Retrieve mail folders");
        SessionData sessionData = RequestUtil.getSessionData(request);
        String language = RequestUtil.getLanguage(request);
        List<Account> accounts = foldersService.getAllMailFolders(sessionData, language);
        AccountsResponseBody accountsResponseBody = new AccountsResponseBody(accounts);
        return RequestUtil.createCachableResponse(request, JacksonUtil.toString(accountsResponseBody));
    }

    @POST
    @Path("/mail/checknew")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response examineFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Examine folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        ExamineFolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, ExamineFolderRequestBody.class);
        ExamineResult result = foldersService.examineFolder(sessionData, requestBody.getFolderId(), requestBody.getValidity(), requestBody.getNext());
        ExamineFolderResponseBody responseBody = new ExamineFolderResponseBody(result);
        return Response.status(result.isChanged() ? 200 : 304).entity(JacksonUtil.toString(responseBody)).build();
    }
}

==> open-xchange-mobile-api-facade_1.2.1.orig.tar.bz2: open-xchange-mobile-api-facade-1.2.1/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/endpoints/FoldersEndpoint.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.endpoints;

import java.util.List;

import javax.annotation.security.PermitAll;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.endpoints.requests.ExamineFolderRequestBody;
import com.openexchange.mobile.api.facade.endpoints.requests.FolderCreateRequestBody;
import com.openexchange.mobile.api.facade.endpoints.requests.FolderRequestBody;
import com.openexchange.mobile.api.facade.endpoints.responses.AccountsResponseBody;
import com.openexchange.mobile.api.facade.endpoints.responses.CreateFolderResponseBody;
import com.openexchange.mobile.api.facade.endpoints.responses.ExamineFolderResponseBody;
import com.openexchange.mobile.api.facade.models.Account;
import com.openexchange.mobile.api.facade.models.CreatedFolder;
import com.openexchange.mobile.api.facade.models.ExamineResult;
import com.openexchange.mobile.api.facade.services.FoldersService;
import com.openexchange.mobile.api.facade.utils.JacksonUtil;
import com.openexchange.mobile.api.facade.utils.RequestUtil;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

@Path("/api-facade/v1/folders")
@RequiredArgsConstructor
@PermitAll
@Slf4j
public class FoldersEndpoint {

    private final FoldersService foldersService;

    @POST
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response createFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Create folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        FolderCreateRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderCreateRequestBody.class);
        CreatedFolder folder = foldersService.createFolder(sessionData, requestBody.getParentFolderId(), requestBody.getName());
        CreateFolderResponseBody responseBody = new CreateFolderResponseBody(folder);
        return RequestUtil.jsonResponse(201, responseBody);
    }

    @DELETE
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response deleteFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Delete folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
        foldersService.deleteFolder(sessionData, requestBody.getFolderId());
        return RequestUtil.emptyJsonResponse();
    }

    @DELETE
    @Path("/clear")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response expungeFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Clear folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
        foldersService.clearFolder(sessionData, requestBody.getFolderId());
        return RequestUtil.emptyJsonResponse();
    }

    @GET
    @Path("/mail")
    @Produces(MediaType.APPLICATION_JSON)
    public Response getAllMailFolders(@Context HttpServletRequest request) {
        log.info("Retrieve mail folders");
        SessionData sessionData = RequestUtil.getSessionData(request);
        String language = RequestUtil.getLanguage(request);
        List<Account> accounts = foldersService.getAllMailFolders(sessionData, language);
        AccountsResponseBody accountsResponseBody = new AccountsResponseBody(accounts);
        return RequestUtil.createCachableResponse(request, accountsResponseBody);
    }

    @POST
    @Path("/mail/checknew")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response examineFolder(@Context HttpServletRequest request, String rawRequestBody) {
        log.info("Examine folder");
        SessionData sessionData = RequestUtil.getSessionData(request);
        ExamineFolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, ExamineFolderRequestBody.class);
        ExamineResult result = foldersService.examineFolder(sessionData, requestBody.getFolderId(), requestBody.getValidity(), requestBody.getNext());
        ExamineFolderResponseBody responseBody = new ExamineFolderResponseBody(result);
        return RequestUtil.jsonResponse(result.isChanged() ? 200 : 304, responseBody);
    }
}
